Contains Cache related structs.

Modules

This module contains the bindings and structs shared with c++

Structs

The main struct for accessing any and all apt data.

Type Definitions

Struct for sorting packages.

Enum for the Package Sorter.

Enum to determine the upgrade type.