pub fn pkg_cache_create() -> UniquePtr<PkgCacheFile>Expand description
Create the CacheFile.
It is advised to init the config and system before creating the cache. These bindings can be found in config::raw.
pub fn pkg_cache_create() -> UniquePtr<PkgCacheFile>Create the CacheFile.
It is advised to init the config and system before creating the cache. These bindings can be found in config::raw.