pub fn pkg_list(
cache: &UniquePtr<PkgCacheFile>,
sort: &PackageSort
) -> Vec<PackagePtr>Expand description
Returns a Vector of all the packages in the cache.
pub fn pkg_list(
cache: &UniquePtr<PkgCacheFile>,
sort: &PackageSort
) -> Vec<PackagePtr>Returns a Vector of all the packages in the cache.