pub fn pkg_provides_list(
cache: &UniquePtr<PkgCacheFile>,
iterator: &PackagePtr,
cand_only: bool
) -> Vec<PackagePtr>Expand description
Return a Vector of all the packages that provide another. steam:i386 provides steam.
pub fn pkg_provides_list(
cache: &UniquePtr<PkgCacheFile>,
iterator: &PackagePtr,
cand_only: bool
) -> Vec<PackagePtr>Return a Vector of all the packages that provide another. steam:i386 provides steam.