#[repr(C)]
pub struct PackageSort { pub names: bool, pub upgradable: Sort, pub virtual_pkgs: Sort, pub installed: Sort, pub auto_installed: Sort, pub auto_removable: Sort, }
Struct for sorting packages.

Fields

names: boolupgradable: Sortvirtual_pkgs: Sortinstalled: Sortauto_installed: Sortauto_removable: Sort

Implementations

Packages will be sorted by their names a -> z.

Only packages that are upgradable will be included.

Only packages that are NOT upgradable will be included.

Virtual packages will be included.

Only Virtual packages will be included.

Only packages that are installed will be included.

Only packages that are NOT installed will be included.

Only packages that are auto installed will be included.

Only packages that are manually installed will be included.

Only packages that are auto removable will be included.

Only packages that are NOT auto removable will be included.