This module contains the bindings and structs shared with c++

Functions

Clears all values from a key.

Clears all configuratations.

Clear a single value from a list. Used for removing one item in an apt configuruation list

Returns a string dump of configuration options separated by \n

Simply check if a key exists.

Find a key and return it’s value as a string.

Same as find, but for boolean values.

Find a directory and return it’s value as a string.

Find a file and return it’s value as a string.

Same as find, but for i32 values.

Return a vector for an Apt configuration list.

Set the given key to the specified value.

init the config. This must occur before creating the cache.

init the system. This must occur before creating the cache.