Contains Package, Version and Dependency Structs.

Modules

This module contains the bindings and structs shared with c++

Structs

A struct representing a Base Dependency

A struct representing an Or_Group of Dependencies

A struct representing an apt Package

A struct representing a version of an apt Package

Enums

Provide which Mark you want to apply on a package.