This module contains the bindings and structs shared with c++

Structs

Struct representing a base dependency.

A wrapper for the BaseDeps to be passed as a list across the barrier.

Functions

Dependency Functions: Return a Vector of all versions that can satisfy a dependency.

Version Functions: Return a Vector of all the dependencies of a version.

Get the fullname of a package. More information on this in the package module.

Get the architecture of a package.

Return the candidate version of the package. Ptr will be NULL if there isn’t a candidate.

Get the current state of a package.

Return the installed version of the package. Ptr will be NULL if it’s not installed.

Return true if the package is essential, otherwise false.

Return the version determined by a version string.

Check if a package provides anything. Virtual packages may provide a real package. This is how you would access the packages to satisfy it.

Check if the package has versions. If a package has no versions it is considered virtual.

Get the ID of a package.

Get the installed state of a package.

Check if the package is installed.

Get the name of the package without the architecture.

Get the selected state of a package.

The architecture of a version.

If the version is able to be downloaded.

The ID of the version.

Check if the version is currently installed.

The uncompressed size of the .deb file.

Return the parent package.

The priority of the package as shown in apt policy.

The priority string as shown in apt show.

The list of package versions that this package provides for. Packages are returned as a vector of strings, with each string being the pkgname and version separated by a ‘/’. If a provided package doesn’t specify a version (i.e. Provides: rustc), the string will end with a slash (rustc/).

The section of the version as shown in apt show.

The size of the .deb file.

The name of the source package the version was built from.

The version of the source package.

The version string of the version. “1.4.10”

Type Definitions