pub fn pkg_has_versions(iterator: &PackagePtr) -> boolExpand description
Check if the package has versions. If a package has no versions it is considered virtual.
pub fn pkg_has_versions(iterator: &PackagePtr) -> boolCheck if the package has versions. If a package has no versions it is considered virtual.