pub struct AptAcquireProgress { /* private fields */ }
AptAcquireProgress is the default struct for the update method on the cache.

This struct mimics the output of apt update.

Implementations

Returns a new default progress instance.

Return the AptAcquireProgress in a box To easily pass through for progress

Returns a disabled progress instance. No output will be shown.