pub struct AptInstallProgress { /* private fields */ }
Default struct to handle the output of a transaction.

Implementations

Return the AptInstallProgress in a box To easily pass through to do_install