#[repr(C)]pub struct ReleaseInfoChange {
pub field: String,
pub old_value: String,
pub new_value: String,
pub message: String,
pub default_action: bool,
}Expand description
A change to repository metadata from its Release file.
Fields
field: StringType of change, such as Origin, Codename, or Version.
old_value: StringPrevious value.
new_value: StringNew value.
message: StringLocalized description supplied by APT.
default_action: boolWhether APT configuration permits this change without confirmation.