pub trait AcquireProgress {
    fn pulse_interval(&self) -> usize;
    fn hit(&mut self, id: u32, description: String);
    fn fetch(&mut self, id: u32, description: String, file_size: u64);
    fn fail(
        &mut self,
        id: u32,
        description: String,
        status: u32,
        error_text: String
    ); fn pulse(
        &mut self,
        workers: Vec<Worker>,
        percent: f32,
        total_bytes: u64,
        current_bytes: u64,
        current_cps: u64
    ); fn done(&mut self); fn start(&mut self); fn stop(
        &mut self,
        fetched_bytes: u64,
        elapsed_time: u64,
        current_cps: u64,
        pending_errors: bool
    ); }
Trait you can impl on any struct to customize the output shown during file downloads.

Required Methods

Called on c++ to set the pulse interval.

Called when an item is confirmed to be up-to-date.

Called when an Item has started to download

Called when an Item fails to download

Called periodically to provide the overall progress information

Called when an item is successfully and completely fetched.

Called when progress has started

Called when progress has finished