DynAcquireProgress

Trait DynAcquireProgress 

pub trait DynAcquireProgress {
    // Required methods
    fn pulse_interval(&self) -> usize;
    fn hit(&mut self, item: &ItemDesc);
    fn fetch(&mut self, item: &ItemDesc);
    fn fail(&mut self, item: &ItemDesc);
    fn pulse(&mut self, status: &AcqTextStatus, owner: &PkgAcquire);
    fn done(&mut self, item: &ItemDesc);
    fn start(&mut self);
    fn stop(&mut self, status: &AcqTextStatus);

    // Provided method
    fn release_info_changes(&mut self, info: ReleaseInfoChanges) -> bool { ... }
}
Customize the output shown during file downloads.

Required Methods

fn pulse_interval(&self) -> usize

Called on c++ to set the pulse interval.

fn hit(&mut self, item: &ItemDesc)

Called when an item is confirmed to be up-to-date.

fn fetch(&mut self, item: &ItemDesc)

Called when an Item has started to download

fn fail(&mut self, item: &ItemDesc)

Called when an Item fails to download

fn pulse(&mut self, status: &AcqTextStatus, owner: &PkgAcquire)

Called periodically to provide the overall progress information

fn done(&mut self, item: &ItemDesc)

Called when an item is successfully and completely fetched.

fn start(&mut self)

Called when progress has started

fn stop(&mut self, status: &AcqTextStatus)

Called when progress has finished

Provided Methods

fn release_info_changes(&mut self, info: ReleaseInfoChanges) -> bool

Called when a repository changes information from its Release file.

Returning true accepts every change. The default accepts changes that APT considers informational or that were allowed through APT configuration, and rejects changes that require explicit confirmation.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors