Module RecordField

Module RecordField 

A module containing &str constants for known record fields

Pass through to the crate::Version::get_record method or you can use a custom &str like the ones listed below.

Other Known Record Keys:

Conffiles Status Python-Version Auto-Built-Package Enhances Cnf-Extra-Commands Gstreamer-Elements Gstreamer-Encoders Lua-Versions Original-Maintainer Protected Gstreamer-Uri-Sources Vendor Build-Ids Efi-Vendor SHA512 Build-Essential Important X-Cargo-Built-Using Cnf-Visible-Pkgname Gstreamer-Decoders SHA1 Gstreamer-Uri-Sinks Gstreamer-Version Ghc-Package Static-Built-Using Postgresql-Catversion Python-Egg-Name Built-Using License Cnf-Ignore-Commands Go-Import-Path Ruby-Versions

Constants

Architecture
The Architecture of the package amd64
Breaks
Packages that are broken by installing this. apt-transport-https (<< 1.5~alpha4~), apt-utils (<< 1.3~exp2~)
Conflicts
Packages that conflict with this one bash-completion (<< 20060301-0)
Depends
Packages this one depends on adduser, gpgv | gpgv2 | gpgv1, libapt-pkg6.0 (>= 2.5.2)
Description
The raw description of the package commandline package manager
DescriptionMD5
The MD5 sum of the description 9fb97a88cb7383934ef963352b53b4a7
Essential
If the package is essential yes
Filename
The raw filename of the package pool/main/a/apt/apt_2.5.2_amd64.deb
Homepage
The homepage of the software https://gitlab.com/volian/rust-apt
InstalledSize
The unpacked size in KiB? 4352
MD5sum
The MD5 sum of the package 8797c5716952fba7779bd072e53acee5
Maintainer
The Maintainer of the package APT Development Team <deity@lists.debian.org>
MultiArch
The type of multi arch for the package. Either allowed, foreign, or same
OriginalMaintainer
The Original Maintainer of the package. Most common to see on Ubuntu packages repackaged from Debian APT Development Team <deity@lists.debian.org>
Package
Name of the package apt
PhasedUpdatePercentage
The percentage rollout value for phased updates 50
PreDepends
Packages that must be installed and configured before this one libc6 (>= 2.34), libtinfo6 (>= 6)
Priority
The Priority of the package required
Provides
Packages that this one provides apt-transport-https (= 2.5.2)
Recommends
Packages that are recommended to be installed with this one ca-certificates
Replaces
Packages that this one replaces apt-transport-https (<< 1.5~alpha4~), apt-utils (<< 1.3~exp2~)
SHA256
The SHA256 sum of the package a6dd99a52ec937faa20e1617da36b8b27a2ed8bc9300bf7eb8404041ede52200
Section
The section of the package admin
Size
The compressed size of the .deb in bytes 1500520
The name of the source package and the version if it exists zsh (5.9-1)
Suggests
Packages that are suggested to be installed with this one apt-doc, aptitude | synaptic | wajig, dpkg-dev (>= 1.17.2)
Tag
Any tags associated with this package admin::package-management, devel::lang:ruby, hardware::storage
Version
Version of the package 2.5.2