This module contains the bindings and structs shared with c++
Structs
Apt C++ Type
A wrapper around PkgFileIterator.
A wrapper around the Apt pkgIterator.
Struct for sorting packages.
Apt C++ Type
Apt C++ Type
Apt C++ Type
Apt C++ Type
Apt C++ Type
Apt C++ Type
Enum to determine what will be sorted.
Struct representing a Source File.
Apt C++ Type
Apt C++ Type
A wrapper around VerFileIterator.
A wrapper around the Apt verIterator.
Functions
The Architecture of the PackageFile. ex: amd64
The Archive of the PackageFile. ex: unstable
Update the package lists, handle errors and return a Result.
The Codename of the PackageFile. ex: main, non-free
The Component of the PackageFile. ex: sid
The path to the PackageFile
The Index of the PackageFile
The Index Type of the PackageFile. Known values are:
The Label of the PackageFile. ex: Debian
The Origin of the PackageFile. ex: Debian
Create the CacheFile.
Return a package by name. Ptr will be NULL if the package doesn’t exist.
Return a package by name and architecture. Ptr will be NULL if the package doesn’t exist.
Return true if the PackageFile is trusted.
Returns a Vector of all the packages in the cache.
Return a Vector of all the packages that provide another. steam:i386 provides steam.
Return a Vector of all the versions of a package.
The Hostname of the PackageFile. ex: deb.debian.org
Get the package list uris. This is the files that are updated with
apt update.
Return a Vector of all the VersionFiles for a version.
Return a Vector of all the PackageFiles for a version.