#[repr(C)]pub struct PackageSort {
pub names: bool,
pub upgradable: Sort,
pub virtual_pkgs: Sort,
pub installed: Sort,
pub auto_installed: Sort,
pub auto_removable: Sort,
}Expand description
Struct for sorting packages.
Fields
names: boolupgradable: Sortvirtual_pkgs: Sortinstalled: Sortauto_installed: Sortauto_removable: SortImplementations
sourceimpl PackageSort
impl PackageSort
sourcepub fn upgradable(self) -> Self
pub fn upgradable(self) -> Self
Only packages that are upgradable will be included.
sourcepub fn not_upgradable(self) -> Self
pub fn not_upgradable(self) -> Self
Only packages that are NOT upgradable will be included.
sourcepub fn include_virtual(self) -> Self
pub fn include_virtual(self) -> Self
Virtual packages will be included.
sourcepub fn only_virtual(self) -> Self
pub fn only_virtual(self) -> Self
Only Virtual packages will be included.
sourcepub fn not_installed(self) -> Self
pub fn not_installed(self) -> Self
Only packages that are NOT installed will be included.
sourcepub fn auto_installed(self) -> Self
pub fn auto_installed(self) -> Self
Only packages that are auto installed will be included.
sourcepub fn manually_installed(self) -> Self
pub fn manually_installed(self) -> Self
Only packages that are manually installed will be included.
sourcepub fn auto_removable(self) -> Self
pub fn auto_removable(self) -> Self
Only packages that are auto removable will be included.
sourcepub fn not_auto_removable(self) -> Self
pub fn not_auto_removable(self) -> Self
Only packages that are NOT auto removable will be included.