pub enum Mark {
Keep,
Auto,
Manual,
Remove,
Purge,
Install,
Reinstall,
NoReinstall,
Downgrade,
Upgrade,
}Expand description
Provide which Mark you want to apply on a package.
Variants
Keep
Mark the package for keep.
Auto
Mark the package as automatically installed.
Manual
Mark the package as manually installed.
Remove
Mark the package for removal.
Purge
Mark the package to remove it and it’s configuration files.
Install
Mark the package for install and mark it manually installed.
This includes the packages dependencies.
Use the mark_install method on the package for finer control.
Reinstall
Mark a package for reinstall.
NoReinstall
Unmark a package for reinstall.
When getting the value this is always inverse of ReInstall.
Downgrade
Check if the package is marked for downgrade.
This currently does not work with pkg.set(). It will panic.
This ability may be implemented in the future.
Upgrade
Check if the package is marked as upgradable
/// When Setting a value this works the same as InstallWithDeps