Contains Progress struct for updating the package list.
Modules
This module contains the bindings and structs shared with c++
Structs
AptAcquireProgress is the default struct for the update method on the cache.
Default struct to handle the output of a transaction.
Traits
Trait you can impl on any struct to customize the output shown during file downloads.
Trait you can impl on any struct to customize the output of installation progress.
Trait you can impl on any struct to customize the output of operation progress on things like opening the cache.