pub trait DynAcquireProgress {
// Required methods
fn pulse_interval(&self) -> usize;
fn hit(&mut self, item: &ItemDesc);
fn fetch(&mut self, item: &ItemDesc);
fn fail(&mut self, item: &ItemDesc);
fn pulse(&mut self, status: &AcqTextStatus, owner: &PkgAcquire);
fn done(&mut self, item: &ItemDesc);
fn start(&mut self);
fn stop(&mut self, status: &AcqTextStatus);
// Provided method
fn release_info_changes(&mut self, info: ReleaseInfoChanges) -> bool { ... }
}Expand description
Customize the output shown during file downloads.
Required Methods
Sourcefn pulse_interval(&self) -> usize
fn pulse_interval(&self) -> usize
Called on c++ to set the pulse interval.
Sourcefn pulse(&mut self, status: &AcqTextStatus, owner: &PkgAcquire)
fn pulse(&mut self, status: &AcqTextStatus, owner: &PkgAcquire)
Called periodically to provide the overall progress information
Sourcefn done(&mut self, item: &ItemDesc)
fn done(&mut self, item: &ItemDesc)
Called when an item is successfully and completely fetched.
Sourcefn stop(&mut self, status: &AcqTextStatus)
fn stop(&mut self, status: &AcqTextStatus)
Called when progress has finished
Provided Methods
Sourcefn release_info_changes(&mut self, info: ReleaseInfoChanges) -> bool
fn release_info_changes(&mut self, info: ReleaseInfoChanges) -> bool
Called when a repository changes information from its Release file.
Returning true accepts every change. The default accepts changes
that APT considers informational or that were allowed through APT
configuration, and rejects changes that require explicit confirmation.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".