Trait rust_apt::progress::OperationProgress
source · [−]pub trait OperationProgress {
fn update(&mut self, operation: String, percent: f32);
fn done(&mut self);
}Expand description
Trait you can impl on any struct to customize the output of operation progress on things like opening the cache.
Required Methods