Contains Records struct for getting extra information about a package.
Some of these functions are accessible on crate::package::Package
structs, please see if that suits your needs first. If not, you can also
access a Records struct on any crate::cache::Cache struct via
crate::cache::Cache::records.
Modules
This module contains the bindings and structs shared with c++
Structs
Internal Struct for managing package records.