This module contains the bindings and structs shared with c++
Structs
A wrapper around the Apt pkgRecords class.
Functions
Moves the Records into the correct place.
Find the hash of a Version.
Return the translated long description of a Package.
Package Record Management: Create the Package Records.
Return the translated short description of a Package.
Moves the Records into the correct place.
Return the URI for a version as determined by it’s package file. A version could have multiple package files and multiple URIs.