This module contains the bindings and structs shared with c++
Functions
Check if the lockfile is locked.
Lock the lockfile.
Lock the Dpkg lockfile.
Unock the lockfile.
Unlock the Dpkg lockfile.
Compares two package versions, ver1 and ver2. The returned
integer’s value is mapped to one of the following integers:
Return an APT-styled progress bar ([####..]).